@@ -48,3 +48,11 @@ def test_ratio_resolve():
         33,
         34,
     ]
+    assert ratio_resolve(
+        50, [Edge(size=30), Edge(ratio=1, minimum_size=10), Edge(size=30)]
+    ) == [30, 10, 30]
+    assert ratio_resolve(110, [Edge(ratio=1), Edge(ratio=1), Edge(ratio=1)]) == [
+        36,
+        37,
+        37,
+    ]
