@@ -2,6 +2,7 @@ from io import StringIO
 
 import pytest
 
+from rich.cells import cell_len
 from rich.segment import ControlType, Segment, SegmentLines, Segments
 from rich.style import Style
 
@@ -284,6 +285,50 @@ def test_split_cells_emoji(text, split, result):
     assert Segment(text).split_cells(split) == result
 
 
+@pytest.mark.parametrize(
+    "segment",
+    [
+        Segment("早乙女リリエル (CV: 徳井青）"),
+        Segment("メイド・イン・きゅんクチュアリ☆    "),
+        Segment("TVアニメ「メルクストーリア -無気力少年と瓶の中の少女-」 主題歌CD"),
+        Segment("南無阿弥JKうらめしや?！     "),
+        Segment("メルク (CV: 水瀬いのり)     "),
+        Segment(" メルク (CV: 水瀬いのり)     "),
+        Segment("  メルク (CV: 水瀬いのり)     "),
+        Segment("  メルク (CV: 水瀬いのり)      "),
+    ],
+)
+def test_split_cells_mixed(segment: Segment) -> None:
+    """Check that split cells splits on cell positions."""
+    # Caused https://github.com/Textualize/textual/issues/4996 in Textual
+
+    for position in range(0, segment.cell_length + 1):
+        left, right = Segment.split_cells(segment, position)
+        assert all(
+            cell_len(c) > 0 for c in segment.text
+        )  # Sanity check there aren't any sneaky control codes
+        assert cell_len(left.text) == position
+        assert cell_len(right.text) == segment.cell_length - position
+
+
+def test_split_cells_doubles() -> None:
+    """Check that split cells splits on cell positions with all double width characters."""
+    test = Segment("早" * 20)
+    for position in range(1, test.cell_length):
+        left, right = Segment.split_cells(test, position)
+        assert cell_len(left.text) == position
+        assert cell_len(right.text) == test.cell_length - position
+
+
+def test_split_cells_single() -> None:
+    """Check that split cells splits on cell positions with all single width characters."""
+    test = Segment("A" * 20)
+    for position in range(1, test.cell_length):
+        left, right = Segment.split_cells(test, position)
+        assert cell_len(left.text) == position
+        assert cell_len(right.text) == test.cell_length - position
+
+
 def test_segment_lines_renderable():
     lines = [[Segment("hello"), Segment(" "), Segment("world")], [Segment("foo")]]
     segment_lines = SegmentLines(lines)
