@@ -1,3 +1,4 @@
+import re
 from io import StringIO
 from typing import List
 
@@ -159,6 +160,7 @@ def test_stylize_negative_index():
 
 
 def test_highlight_regex():
+    # As a string
     text = Text("peek-a-boo")
 
     count = text.highlight_regex(r"NEVER_MATCH", "red")
@@ -176,6 +178,7 @@ def test_highlight_regex():
     ]
 
     text = Text("Ada Lovelace, Alan Turing")
+
     count = text.highlight_regex(
         r"(?P<yellow>[A-Za-z]+)[ ]+(?P<red>[A-Za-z]+)(?P<NEVER_MATCH>NEVER_MATCH)*"
     )
@@ -189,16 +192,52 @@ def test_highlight_regex():
         Span(19, 25, "red"),  # Turing
     ]
 
+    # As a regular expression object
+    text = Text("peek-a-boo")
+
+    count = text.highlight_regex(re.compile(r"NEVER_MATCH"), "red")
+    assert count == 0
+    assert len(text._spans) == 0
+
+    # text: peek-a-boo
+    # indx: 0123456789
+    count = text.highlight_regex(re.compile(r"[a|e|o]+"), "red")
+    assert count == 3
+    assert sorted(text._spans) == [
+        Span(1, 3, "red"),
+        Span(5, 6, "red"),
+        Span(8, 10, "red"),
+    ]
+
+    text = Text("Ada Lovelace, Alan Turing")
+
+    count = text.highlight_regex(
+        re.compile(
+            r"(?P<yellow>[A-Za-z]+)[ ]+(?P<red>[A-Za-z]+)(?P<NEVER_MATCH>NEVER_MATCH)*"
+        )
+    )
+
+    # The number of matched name should be 2
+    assert count == 2
+    assert sorted(text._spans) == [
+        Span(0, 3, "yellow"),  # Ada
+        Span(4, 12, "red"),  # Lovelace
+        Span(14, 18, "yellow"),  # Alan
+        Span(19, 25, "red"),  # Turing
+    ]
+
 
 def test_highlight_regex_callable():
     text = Text("Vulnerability CVE-2018-6543 detected")
     re_cve = r"CVE-\d{4}-\d+"
+    compiled_re_cve = re.compile(r"CVE-\d{4}-\d+")
 
     def get_style(text: str) -> Style:
         return Style.parse(
             f"bold yellow link https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword={text}"
         )
 
+    # string
     count = text.highlight_regex(re_cve, get_style)
     assert count == 1
     assert len(text._spans) == 1
@@ -209,6 +248,20 @@ def test_highlight_regex_callable():
         == "https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE-2018-6543"
     )
 
+    # Clear the tracked _spans for the regular expression object's use
+    text._spans.clear()
+
+    # regular expression object
+    count = text.highlight_regex(compiled_re_cve, get_style)
+    assert count == 1
+    assert len(text._spans) == 1
+    assert text._spans[0].start == 14
+    assert text._spans[0].end == 27
+    assert (
+        text._spans[0].style.link
+        == "https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE-2018-6543"
+    )
+
 
 def test_highlight_words():
     text = Text("Do NOT! touch anything!")
@@ -981,3 +1034,34 @@ def test_extend_style():
     text.extend_style(2)
     assert text.plain == "foo bar  "
     assert text.spans == [Span(0, 3, "red"), Span(4, 9, "bold")]
+
+
+def test_append_tokens() -> None:
+    """Regression test for https://github.com/Textualize/rich/issues/3014"""
+
+    console = Console()
+    t = Text().append_tokens(
+        [
+            (
+                "long text that will be wrapped with a control code \r\n",
+                "red",
+            ),
+        ]
+    )
+    with console.capture() as capture:
+        console.print(t, width=40)
+
+    output = capture.get()
+    print(repr(output))
+    assert output == "long text that will be wrapped with a \ncontrol code \n\n"
+
+
+def test_append_loop_regression() -> None:
+    """Regression text for https://github.com/Textualize/rich/issues/3479"""
+    a = Text("one", "blue")
+    a.append(a)
+    assert a.plain == "oneone"
+
+    b = Text("two", "blue")
+    b.append_text(b)
+    assert b.plain == "twotwo"
